;;****************************************************************************
;; FileName : WDLIB.ASM
;; Function : Control Watch Dog Time Out.(for SMsC 37B787)
;; Design's : By Todd
;; BuildDate: 01/10/2002 V1.0
;;****************************************************************************

;;Function declare as follows:
PUBLIC  InitWD          ;;initial watch dog
PUBLIC  EnWD            ;;enable watch dog
PUBLIC  DisWD           ;;disable watch dog
PUBLIC  OpenIoConfig    ;;open super IO of configuration register for SMsC 37B787
PUBLIC  CloseIoConfig   ;;close super IO of configuration register for SMsC 37B787
PUBLIC  SelectIoDevice  ;;select super IO of device for SMsC 37B787
PUBLIC  WriteIoCR       ;;write super IO of configuration register for SMsC 37B787
PUBLIC  ReadIoCR        ;;read super IO of configuration register for SMsC 37B787

;;Default value define as follows:
equIndexPort EQU 3f0h   ;;super IO of index port for SMsC 37B787
equDataPort  EQU 3f1h   ;;super IO of data port for SMsC 37B787
equDeviceCR  EQU 07h    ;;select super IO device of index port for SMsC 37B787
equLockReg   EQU 0aah   ;;lock super IO of configuration register for SMsC 37B787
equUnlockReg EQU 55h    ;;unlock super IO of configuration register for SMsC 37B787

        .model  small
        .code
WatchDogLib:
;;
;;==========================================================================;;
;; OpenIoConfig                                                             ;;
;;==========================================================================;;
;; Function : open super IO of configuration register for SMsC 37B787       ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
OpenIoConfig:
        mov     dx,equIndexPort ;;super IO of index port for SMsC 37B787
        mov     al,equUnlockReg ;;unlock super IO of configuration register for smsc 37b787
        out     dx,al
        nop
        out     dx,al
        ret
;;
;;==========================================================================;;
;; CloseIoConfig                                                            ;;
;;==========================================================================;;
;; Function : close super IO of configuration register for SMsC 37B787      ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
CloseIoConfig:
        mov     dx,equIndexPort ;;super IO of index port for SMsC 37B787
        mov     al,equLockReg   ;;lock super IO of configuration register for smsc 37b787
        out     dx,al
        ret
;;
;;==========================================================================;;
;; SelectIoDevice                                                           ;;
;;==========================================================================;;
;; Function : select super IO of device for SMsC 37B787                     ;;
;; Enter    : AH = select device of function                                ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;
SelectIoDevice:
        mov     dx,equIndexPort ;;super IO of index port for smsc 37b787
        mov     al,equDeviceCR  ;;select super IO device of index port for SMsC 37B787
        out     dx,al

        mov     dx,equDataPort  ;;super IO of data port for SMsC 37B787
        xchg    al,ah           ;;select device of function
        out     dx,al
        ret
;;
;;==========================================================================;;
;; WriteIoCR                                                                ;;
;;==========================================================================;;
;; Function : write super IO of configuration register for SMsC 37B787      ;;
;; Enter    : AL = select index port of configuration register(CR)          ;;
;;            AH = configuration register of data                           ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;
WriteIoCR:
        mov     dx,equIndexPort ;;super IO of index port for SMsC 37B787
        out     dx,al

        mov     dx,equDataPort  ;;super IO of data port for SMsC 37B787
        xchg    al,ah           ;;configuration register of data
        out     dx,al
        ret
;;
;;==========================================================================;;
;; ReadIoCR                                                                 ;;
;;==========================================================================;;
;; Function : read super IO of configuration register for SMsC 37B787       ;;
;; Enter    : AL = select index port of configuration register(CR)          ;;
;; Return   : AL = configuration register of data                           ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
ReadIoCR:
        mov     dx,equIndexPort ;;super IO of index port for SMsC 37B787
        out     dx,al

        mov     dx,equDataPort  ;;super IO of data port for SMsC 37B787
        in      al,dx           ;;configuration register of data
        ret
;;
;;==========================================================================;;
;; InitWD                                                                   ;;
;;==========================================================================;;
;; Function : initial watch dog                                             ;;
;; Enter    : BL = watch dog counter of unit                                ;;
;;                 00h : minute                                             ;;
;;                 80h : second                                             ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
InitWD:
        push    ax
        push    bx
        push    dx

        call    OpenIoConfig    ;;open super IO of configuration for SMsC 37B787

        mov     ah,08h          ;;select device8
        call    SelectIoDevice

        mov     ax,08e3h	;;select 37b787 pin 80=led not Gpio
        call    WriteIoCR

        mov     ax,0ae2h	;;select 37b787 pin 79=wdt not Gpio,and=output,and polarity=invert 
        call    WriteIoCR

        mov     al,0f1h        ;;select watch dog counter of unit,read demo progrom bl=unit
        call    ReadIoCR		;;00=min,80=sec
        and     al,01111111b
        or      al,bl
        mov     ah,0f1h
        xchg    ah,al
        call    WriteIoCR

        call    CloseIoConfig

        pop     dx
        pop     bx
        pop     ax
        ret
;;
;;==========================================================================;;
;; EnWD                                                                     ;;
;;==========================================================================;;
;; Function : Enable watch dog                                              ;;
;; Enter    : BL = watch dog time out of value                              ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
EnWD:
        push    ax
        push    bx
        push    dx

        call    OpenIoConfig    ;;open super IO of configuration for smsc 37b787

        mov     ah,08h          ;;select device8
        call    SelectIoDevice

        mov     al,0f2h		;;wdt value form bl
        mov     ah,bl
        call    WriteIoCR

        mov     ax,08f3h	;;enable wdt time out active 08=reset,10=IRQ1,30=IRQ3,f0=IRQ15
        call    WriteIoCR

        call    CloseIoConfig

        pop     dx
        pop     bx
        pop     ax
        ret
;;
;;==========================================================================;;
;; DisWD                                                                    ;;
;;==========================================================================;;
;; Function : Disable watch dog                                             ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
DisWD:
        push    ax
        push    dx

        call    OpenIoConfig    ;;open super IO of configuration for smsc 37b787

        mov     ah,08h          ;;select device8
        call    SelectIoDevice

        mov     ax,09e3h
        call    WriteIoCR

        mov     ax,09e2h
        call    WriteIoCR

        mov     ax,00f3h
        call    WriteIoCR

        mov     ax,00f2h
        call    WriteIoCR

        call    CloseIoConfig   ;;close super IO of configuration for smsc 37b787

        pop     dx
        pop     ax
        ret
;;
;;==================== END ====================
        END     WatchDogLib
