//****************************************************************************
// FileName : WDLIB.H
// Function : Watch Dog Function Define of Include File
// Design's : By Ray
// BuildDate: 01/10/2002 V1.0
//****************************************************************************
#ifndef __WDLIB_H
#define __WDLIB_H

#ifndef __DOS_H
  #include <dos.h>
#endif

//Default value define as follows:
#define equWdUnitS 0x80 //watch dog counter value of unit is second
#define equWdUnitM 0x00 //watch dog counter value of unit is minute

#ifdef __cplusplus
extern "C" {
#endif

//==========================================================================//
// InitWD                                                                   //
//==========================================================================//
// Function : Initial watch dog                                             //
// Input    : cSetWatchDogUnit = watch dog counter of unit                  //
//               00h : minute                                               //
//               80h : second                                               //
// Return   : None                                                          //
//==========================================================================//
void InitWD(char cSetWatchDogUnit);

//==========================================================================//
// EnWD                                                                     //
//==========================================================================//
// Function : Enable watch dog                                              //
// Input    : cWatchDogValue = watch dog time out of value                  //
// Return   : None                                                          //
//==========================================================================//
void EnWD(char cWatchDogValue);

//==========================================================================//
// DisWD                                                                    //
//==========================================================================//
// Function : Disable watch dog                                             //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void DisWD(void);


/*Direct control register for IO SMsC 37B787
  (Referance the detail information of data sheet)*/
//==========================================================================//
// OpenIoConfig                                                             //
//==========================================================================//
// Function : Enable register with SMsC 37B787                              //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void OpenIoConfig(void);

//==========================================================================//
// CloseIoConfig                                                            //
//==========================================================================//
// Function : Disable register with SMsC 37B787                             //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void CloseIoConfig(void);

//==========================================================================//
// SelectIoDevice                                                           //
//==========================================================================//
// Function : Select Watchdog or another device                             //
// Input    : cSelectDEV = select device of function                        //
// Return   : None                                                          //
//==========================================================================//
void SelectIoDevice(char cSelectDEV);

//==========================================================================//
// WriteIoCR                                                                //
//==========================================================================//
// Function : Write index data configuration register                       //
// Input    : cIndex = select index port of configuration register(CR)      //
//            cData  = configuration register of data                       //
// Return   : None                                                          //
//==========================================================================//
void WriteIoCR(char cIndex, char cData);

//==========================================================================//
// ReadIoCR                                                                 //
//==========================================================================//
// Function : Read index data configuration register                        //
// Input    : cIndex = select index port of configuration register(CR)      //
// Return   : configuration register of data                                //
//==========================================================================//
char ReadIoCR(char cIndex);

#ifdef __cplusplus
}
#endif

#endif  // __WDLIB_H
