//****************************************************************************
// FileName : WDLIB.CPP
// Function : Control Watch Dog Time Out.(for SMsC 37B787)
// Design's : By Ray
// BuildDate: 01/10/2002 V1.0
//****************************************************************************

//Include file as follows:
#include "wdlib.h"
#include <stdio.h>
#include <conio.h>

//Default value define as follows:
#define	equIndexPort	0x3f0	//super IO of index port for SMsC 37B787
#define equDataPort	0x3f1	//super IO of data port for SMsC 37B787
#define	equDeviceCR	0x07    //select super IO device of index port for SMsC 37B787
#define	equLockReg	0xaa	//lock super IO of configuration register for SMsC 37B787
#define	equUnlockReg	0x55	//unlock super IO of configuration register for SMsC 37B787

//==========================================================================//
// OpenIoConfig                                                             //
//==========================================================================//
// Function : open super IO of configuration register for SMsC 37B787       //
// Enter    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void OpenIoConfig()
{
//super IO of index port for SMsC 37B787
//unlock super IO of configuration register for SMsC 37B787
outportb(equIndexPort,equUnlockReg);
outportb(equIndexPort,equUnlockReg);
}

//==========================================================================//
// CloseIoConfig                                                            //
//==========================================================================//
// Function : close super IO of configuration register for SMsC 37B787      //
// Enter    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void CloseIoConfig()
{
//super IO of index port for SMsC 37B787
//lock super IO of configuration register for SMsC 37B787
outportb(equIndexPort,equLockReg);
}

//==========================================================================//
// SelectIoDevice                                                           //
//==========================================================================//
// Function : select super IO of device for SMsC 37B787                     //
// Enter    : cSelectDEV = select device of function                        //
// Return   : None                                                          //
//==========================================================================//
void SelectIoDevice(char cSelectDEV)
{
//super IO of index port for SMsC 37B787
//select super IO device of index port for SMsC 37B787
outportb(equIndexPort,equDeviceCR);

//super IO of data for SMsC 37B787
//select device of function
outportb(equDataPort,cSelectDEV);
}

//==========================================================================//
// WriteIoCR                                                                //
//==========================================================================//
// Function : write super IO of configuration register for SMsC 37B787      //
// Enter    : cIndex = select index port of configuration register(CR)      //
//            cData  = configuration register of data                       //
// Return   : None                                                          //
//==========================================================================//
void WriteIoCR(char cIndex, char cData)
{
//super IO of index port for SMsC 37B787
//select super IO of index register for SMsC 37B787
outportb(equIndexPort,cIndex);

//super IO of data for SMsC 37B787
//write data to data register
outportb(equDataPort,cData);
}

//==========================================================================//
// ReadIoCR                                                                 //
//==========================================================================//
// Function : read super IO of configuration register for SMsC 37B787       //
// Enter    : cIndex = select index port of configuration register(CR)      //
// Return   : configuration register of data		                    //
//==========================================================================//
char ReadIoCR(char cIndex)
{
//super IO of index port for SMsC 37B787
//select super IO of index register for SMsC 37B787
outportb(equIndexPort,cIndex);

//super IO of index port for SMsC 37B787
//read data form index register
return (inportb(equDataPort));
}

//==========================================================================//
// InitWD                                                                   //
//==========================================================================//
// Function : initial watch dog                                             //
// Enter    : cSetWatchDogUnit = watch dog counter of unit                  //
//               00h : minute                                               //
//               80h : second                                               //
// Return   : None                                                          //
//==========================================================================//
void InitWD(char cSetWatchDogUnit)
{
char cUnit;
OpenIoConfig();		//open super IO of configuration for SMsC 37B787

SelectIoDevice(0x08);	//select device8

WriteIoCR(0xe3,0x08);	//CRE3 = 08h select pin80=led not GPIO

WriteIoCR(0xe2,0x0a);	//CRE2 = 0Ah set pin 79=wdt not Gpio,and=output,and polarity=invert

cUnit=ReadIoCR(0xf1);	//read CRF1 of data
//set watch dog counter of unit
WriteIoCR(0xf1,((cUnit&0x7f)|cSetWatchDogUnit));
}

//==========================================================================//
// EnWD                                                                     //
//==========================================================================//
// Function : Enable watch dog                                              //
// Enter    : cWatchDogValue = watch dog time out of value                  //
// Return   : None                                                          //
//==========================================================================//
void EnWD(char cWatchDogValue)
{
OpenIoConfig();			//open super IO of configuration for SMsC 37b787

SelectIoDevice(0x08);		//select device8

//enable watch dog, WDT=cWatchDogValue
WriteIoCR(0xf2,cWatchDogValue);

//enable wdt time out active 08=reset,10=IRQ1,30=IRQ3,f0=IRQ15
WriteIoCR(0xf3,0x08);
}

//==========================================================================//
// DisWD                                                                    //
//==========================================================================//
// Function : Disable watch dog                                             //
// Enter    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void DisWD()
{
SelectIoDevice(0x08);		//select device8

WriteIoCR(0xe3,0x09);

WriteIoCR(0xe2,0x09);

WriteIoCR(0xf3,0x00);

WriteIoCR(0xf2,0x00);

CloseIoConfig();		//close super IO of configuration for winbond 83977EF
}
